@@ -356,12 +356,13 @@ QString Application::mimeType(QUrl url)
     return fileItem.mimetype();
 }
 
-void Application::handleSecondayInstanceMessage(const QByteArray &message)
+void Application::handleSecondayInstanceMessage(const QByteArray &message, const QString activationToken)
 {
     auto msgString = QString::fromStdString(message.data());
     QFileInfo fileInfo{msgString};
     if (fileInfo.exists() && fileInfo.isFile()) {
         Q_EMIT openUrl(QUrl::fromUserInput(msgString));
+        qputenv("XDG_ACTIVATION_TOKEN", activationToken.toUtf8());
         raiseWindow();
     }
 }
@@ -427,13 +428,14 @@ QString Application::platformName()
 
 void Application::raiseWindow()
 {
-    QObject *m_rootObject = m_qmlEngine->rootObjects().constFirst();
-    if (!m_rootObject) {
+    QObject *rootObject = m_qmlEngine->rootObjects().constFirst();
+    if (!rootObject) {
         return;
     }
 
-    QWindow *window = qobject_cast<QWindow *>(m_rootObject);
+    QWindow *window = qobject_cast<QWindow *>(rootObject);
     if (window) {
+        KWindowSystem::updateStartupId(window);
         KWindowSystem::activateWindow(window);
     }
 }
