@@ -28,12 +28,16 @@ public:
         StartTimeRole,
     };
 
+    Q_PROPERTY(int rowCount READ rowCount NOTIFY rowCountChanged)
     int rowCount(const QModelIndex &parent = QModelIndex()) const override;
     QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const override;
     QHash<int, QByteArray> roleNames() const override;
 
     void setChapters(QList<Chapter> &_chapters);
 
+Q_SIGNALS:
+    void rowCountChanged();
+
 private:
     QList<Chapter> m_chapters;
 };
