@@ -6,13 +6,6 @@
 
 #include "playlistmodel.h"
 
-#include <KFileItem>
-#include <KFileMetaData/Properties>
-#include <KIO/DeleteOrTrashJob>
-#include <KIO/OpenFileManagerWindowJob>
-#include <KIO/RenameFileDialog>
-#include <kio_version.h>
-
 #include <QClipboard>
 #include <QCollator>
 #include <QDirIterator>
@@ -23,11 +16,20 @@
 #include <QJsonValue>
 #include <QProcess>
 
+#include <KFileItem>
+#include <KFileMetaData/Properties>
+#include <KIO/DeleteOrTrashJob>
+#include <KIO/OpenFileManagerWindowJob>
+#include <KIO/RenameFileDialog>
+#include <kio_version.h>
+
 #include "application.h"
 #include "generalsettings.h"
 #include "playlistsettings.h"
 #include "worker.h"
 
+using namespace Qt::StringLiterals;
+
 PlaylistModel::PlaylistModel(QObject *parent)
     : QAbstractListModel(parent)
 {
@@ -71,11 +73,11 @@ QVariant PlaylistModel::data(const QModelIndex &index, int role) const
     case DurationRole:
         return QVariant(item.formattedDuration);
     case PlayingRole:
-        return QVariant(m_playingItem == index.row());
+        return QVariant(static_cast<int>(m_playingItem) == index.row());
     case FolderPathRole:
         return QVariant(item.folderPath);
     case IsLocalRole:
-        return QVariant(!item.url.scheme().startsWith(QStringLiteral("http")));
+        return QVariant(!item.url.scheme().startsWith(u"http"_s));
     }
 
     return QVariant();
@@ -83,15 +85,18 @@ QVariant PlaylistModel::data(const QModelIndex &index, int role) const
 
 QHash<int, QByteArray> PlaylistModel::roleNames() const
 {
+    // clang-format off
     QHash<int, QByteArray> roles = {
-        {NameRole, "name"},
-        {TitleRole, "title"},
-        {PathRole, "path"},
-        {FolderPathRole, "folderPath"},
-        {DurationRole, "duration"},
-        {PlayingRole, "isPlaying"},
-        {IsLocalRole, "isLocal"},
+        {NameRole,       QByteArrayLiteral("name")},
+        {TitleRole,      QByteArrayLiteral("title")},
+        {PathRole,       QByteArrayLiteral("path")},
+        {FolderPathRole, QByteArrayLiteral("folderPath")},
+        {DurationRole,   QByteArrayLiteral("duration")},
+        {PlayingRole,    QByteArrayLiteral("isPlaying")},
+        {IsLocalRole,    QByteArrayLiteral("isLocal")},
     };
+    // clang-format on
+
     return roles;
 }
 
@@ -119,10 +124,10 @@ void PlaylistModel::addItem(const QUrl &url, Behaviour behaviour)
         clear();
     }
 
-    if (url.scheme() == QStringLiteral("file")) {
+    if (url.scheme() == u"file"_s) {
         auto mimeType = Application::mimeType(url);
 
-        if (mimeType == QStringLiteral("audio/x-mpegurl")) {
+        if (mimeType == u"audio/x-mpegurl"_s) {
             m_playlistPath = url.toString();
             addM3uItems(url);
             return;
@@ -144,7 +149,7 @@ void PlaylistModel::addItem(const QUrl &url, Behaviour behaviour)
         }
     }
 
-    if (url.scheme() == QStringLiteral("http") || url.scheme() == QStringLiteral("https")) {
+    if (url.scheme() == u"http"_s || url.scheme() == u"https"_s) {
         if (Application::isYoutubePlaylist(url.toString())) {
             m_playlistPath = url.toString();
             getYouTubePlaylist(url, behaviour);
@@ -169,7 +174,7 @@ void PlaylistModel::appendItem(const QUrl &url)
         item.filename = itemInfo.fileName();
         item.folderPath = itemInfo.absolutePath();
     } else {
-        if (url.scheme().startsWith(QStringLiteral("http"))) {
+        if (url.scheme().startsWith(u"http"_s)) {
             item.url = url;
             item.filename = url.toString();
             // causes issues with lots of links
@@ -239,7 +244,7 @@ void PlaylistModel::getSiblingItems(const QUrl &url)
 
 void PlaylistModel::addM3uItems(const QUrl &url)
 {
-    if (url.scheme() != QStringLiteral("file") || Application::mimeType(url) != QStringLiteral("audio/x-mpegurl")) {
+    if (url.scheme() != u"file"_s || Application::mimeType(url) != u"audio/x-mpegurl"_s) {
         return;
     }
 
@@ -284,25 +289,25 @@ void PlaylistModel::getYouTubePlaylist(const QUrl &url, Behaviour behaviour)
 {
     // use youtube-dl to get the required playlist info as json
     auto ytdlProcess = std::make_shared<QProcess>();
-    auto args = QStringList() << QStringLiteral("-J") << QStringLiteral("--flat-playlist") << url.toString();
+    auto args = QStringList() << u"-J"_s << u"--flat-playlist"_s << url.toString();
     ytdlProcess->setProgram(Application::youtubeDlExecutable());
     ytdlProcess->setArguments(args);
     ytdlProcess->start();
 
     connect(ytdlProcess.get(), QOverload<int, QProcess::ExitStatus>::of(&QProcess::finished), this, [=](int, QProcess::ExitStatus) {
         QString json = QString::fromUtf8(ytdlProcess->readAllStandardOutput());
-        QJsonValue entries = QJsonDocument::fromJson(json.toUtf8())[QStringLiteral("entries")];
-        // QString playlistTitle = QJsonDocument::fromJson(json.toUtf8())[QStringLiteral("title")].toString();
+        QJsonValue entries = QJsonDocument::fromJson(json.toUtf8())[u"entries"_s];
+        // QString playlistTitle = QJsonDocument::fromJson(json.toUtf8())[u"title")].toString();
         if (entries.toArray().isEmpty()) {
             return;
         }
 
         bool matchFound{false};
         for (int i = 0; i < entries.toArray().size(); ++i) {
-            auto id = entries[i][QStringLiteral("id")].toString();
-            auto url = QStringLiteral("https://youtu.be/%1").arg(entries[i][QStringLiteral("id")].toString());
-            auto title = entries[i][QStringLiteral("title")].toString();
-            auto duration = entries[i][QStringLiteral("duration")].toDouble();
+            auto id = entries[i][u"id"_s].toString();
+            auto url = u"https://youtu.be/%1"_s.arg(entries[i][u"id"_s].toString());
+            auto title = entries[i][u"title"_s].toString();
+            auto duration = entries[i][u"duration"_s].toDouble();
 
             PlaylistItem item;
             item.url = QUrl::fromUserInput(url);
@@ -328,17 +333,17 @@ void PlaylistModel::getYouTubePlaylist(const QUrl &url, Behaviour behaviour)
     });
 }
 
-void PlaylistModel::getHttpItemInfo(const QUrl &url, int row)
+void PlaylistModel::getHttpItemInfo(const QUrl &url, uint row)
 {
     auto ytdlProcess = std::make_shared<QProcess>();
     ytdlProcess->setProgram(Application::youtubeDlExecutable());
-    ytdlProcess->setArguments(QStringList() << QStringLiteral("-j") << url.toString());
+    ytdlProcess->setArguments(QStringList() << u"-j"_s << url.toString());
     ytdlProcess->start();
 
     connect(ytdlProcess.get(), QOverload<int, QProcess::ExitStatus>::of(&QProcess::finished), this, [=](int, QProcess::ExitStatus) {
         QString json = QString::fromUtf8(ytdlProcess->readAllStandardOutput());
-        QString title = QJsonDocument::fromJson(json.toUtf8())[QStringLiteral("title")].toString();
-        auto duration = QJsonDocument::fromJson(json.toUtf8())[QStringLiteral("duration")].toDouble();
+        QString title = QJsonDocument::fromJson(json.toUtf8())[u"title"_s].toString();
+        auto duration = QJsonDocument::fromJson(json.toUtf8())[u"duration"_s].toDouble();
         if (title.isEmpty()) {
             // todo: log if can't get title
             return;
@@ -355,20 +360,20 @@ void PlaylistModel::getHttpItemInfo(const QUrl &url, int row)
 bool PlaylistModel::isVideoOrAudioMimeType(const QString &mimeType)
 {
     // clang-format off
-    return (mimeType.startsWith(QStringLiteral("video/"))
-            || mimeType.startsWith(QStringLiteral("audio/"))
-            || mimeType == QStringLiteral("application/vnd.rn-realmedia"))
-            && mimeType != QStringLiteral("audio/x-mpegurl");
+    return (mimeType.startsWith(u"video/"_s)
+            || mimeType.startsWith(u"audio/"_s)
+            || mimeType == u"application/vnd.rn-realmedia"_s)
+            && mimeType != u"audio/x-mpegurl"_s;
     // clang-format on
 }
 
-void PlaylistModel::setPlayingItem(int i)
+void PlaylistModel::setPlayingItem(uint i)
 {
-    if (i < -1 || i >= m_playlist.size()) {
+    if (i >= m_playlist.size()) {
         return;
     }
 
-    int previousItem{m_playingItem};
+    uint previousItem{m_playingItem};
     m_playingItem = i;
     Q_EMIT dataChanged(index(previousItem, 0), index(previousItem, 0));
     Q_EMIT dataChanged(index(i, 0), index(i, 0));
@@ -412,13 +417,13 @@ void PlaylistProxyModel::sortItems(Sort sortMode)
     }
 }
 
-int PlaylistProxyModel::getPlayingItem()
+uint PlaylistProxyModel::getPlayingItem()
 {
     auto model = qobject_cast<PlaylistModel *>(sourceModel());
     return mapFromSource(model->index(model->m_playingItem, 0)).row();
 }
 
-void PlaylistProxyModel::setPlayingItem(int i)
+void PlaylistProxyModel::setPlayingItem(uint i)
 {
     auto model = qobject_cast<PlaylistModel *>(sourceModel());
     model->setPlayingItem(mapToSource(index(i, 0)).row());
@@ -464,13 +469,13 @@ void PlaylistProxyModel::saveM3uFile(const QString &path)
     m3uFile.close();
 }
 
-void PlaylistProxyModel::highlightInFileManager(int row)
+void PlaylistProxyModel::highlightInFileManager(uint row)
 {
     QString path = data(index(row, 0), PlaylistModel::PathRole).toString();
     KIO::highlightInFileManager({QUrl::fromUserInput(path)});
 }
 
-void PlaylistProxyModel::removeItem(int row)
+void PlaylistProxyModel::removeItem(uint row)
 {
     auto model = qobject_cast<PlaylistModel *>(sourceModel());
 
@@ -481,12 +486,12 @@ void PlaylistProxyModel::removeItem(int row)
     endRemoveRows();
 }
 
-void PlaylistProxyModel::renameFile(int row)
+void PlaylistProxyModel::renameFile(uint row)
 {
     QString path = data(index(row, 0), PlaylistModel::PathRole).toString();
     QUrl url(path);
     if (url.scheme().isEmpty()) {
-        url.setScheme(QStringLiteral("file"));
+        url.setScheme(u"file"_s);
     }
     KFileItem item(url);
     auto renameDialog = new KIO::RenameFileDialog(KFileItemList({item}), nullptr);
@@ -503,13 +508,13 @@ void PlaylistProxyModel::renameFile(int row)
     });
 }
 
-void PlaylistProxyModel::trashFile(int row)
+void PlaylistProxyModel::trashFile(uint row)
 {
     QList<QUrl> urls;
     QString path = data(index(row, 0), PlaylistModel::PathRole).toString();
     QUrl url(path);
     if (url.scheme().isEmpty()) {
-        url.setScheme(QStringLiteral("file"));
+        url.setScheme(u"file"_s);
     }
     urls << url;
     auto *job = new KIO::DeleteOrTrashJob(urls, KIO::AskUserActionInterface::Trash, KIO::AskUserActionInterface::DefaultConfirmation, this);
@@ -526,25 +531,30 @@ void PlaylistProxyModel::trashFile(int row)
     });
 }
 
-void PlaylistProxyModel::copyFileName(int row)
+void PlaylistProxyModel::copyFileName(uint row)
 {
     auto model = qobject_cast<PlaylistModel *>(sourceModel());
     auto item = model->m_playlist.at(row);
     QGuiApplication::clipboard()->setText(item.filename);
 }
 
-void PlaylistProxyModel::copyFilePath(int row)
+void PlaylistProxyModel::copyFilePath(uint row)
 {
     auto model = qobject_cast<PlaylistModel *>(sourceModel());
     auto item = model->m_playlist.at(row);
     QGuiApplication::clipboard()->setText(item.url.toString());
 }
 
-QString PlaylistProxyModel::getFilePath(int row)
+QString PlaylistProxyModel::getFilePath(uint row)
 {
     auto model = qobject_cast<PlaylistModel *>(sourceModel());
     auto item = model->m_playlist.at(row);
     return item.url.toString();
 }
 
+bool PlaylistProxyModel::isLastItem(uint row)
+{
+    return static_cast<int>(row) == rowCount() - 1;
+}
+
 #include "moc_playlistmodel.cpp"
