@@ -8,8 +8,10 @@
 #define RECENTFILESMODEL_H
 
 #include <KConfigGroup>
+
 #include <QAbstractListModel>
 #include <QUrl>
+#include <QtQml/qqmlregistration.h>
 
 class KRecentFilesAction;
 
@@ -21,6 +23,8 @@ struct RecentFile {
 class RecentFilesModel : public QAbstractListModel
 {
     Q_OBJECT
+    QML_NAMED_ELEMENT(RecentFilesModel)
+
 public:
     explicit RecentFilesModel(QObject *parent = nullptr);
 
