@@ -8,10 +8,12 @@
 #define SUBTITLESFOLDERSMODEL_H
 
 #include <QAbstractListModel>
+#include <QtQml/qqmlregistration.h>
 
 class SubtitlesFoldersModel : public QAbstractListModel
 {
     Q_OBJECT
+    QML_NAMED_ELEMENT(SubtitlesFoldersModel)
 
 public:
     explicit SubtitlesFoldersModel(QObject *parent = nullptr);
@@ -21,7 +23,7 @@ public:
 
     QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const override;
 
-public slots:
+public Q_SLOTS:
     void updateFolder(const QString &folder, int row);
     void deleteFolder(int row);
     void addFolder();
